# Zeno View for Image Classification

## Install

Install the package from PyPI:

```
pip install zenoml_image_classification
```

And pass as the `task` argument to a Zeno `.toml` file.

### [Follow the documentation to get started](https://dig.cmu.edu/zeno/intro.html)
